% A script for running Monte Carlo simulations on the central.m script and
% producing box plots.

%% Initiating the variables:
n_iterations=10000;

zest_two = zeros(n_iterations,length(kvec));
zest_conv = zeros(n_iterations,length(kvec));

zpre_two = zeros(n_iterations,length(kvec));
z_conv = zeros(n_iterations,length(kvec));
zest_two_without = zeros(n_iterations,length(kvec));

%% Running Monte Carlo simulations
for iteration = 1:n_iterations
    
    central; %running central.m script (display should be set to false within central.m)
    
    %Estimated power flows from substation 2 to substation 1:
    zest_two_without(iteration) = V0(2)^2*4.9991 - V0(1)*V0(2)*(4.9991*cos((Del0(2)-Del0(1))*pi/180) - 15.2631*sin((Del0(2)-Del0(1))*pi/180));
    zest_two(iteration) = V(2)^2*4.9991 - V(1)*V(2)*(4.9991*cos((Del(2)-Del(1))*pi/180) - 15.2631*sin((Del(2)-Del(1))*pi/180));
    zest_conv(iteration) = V2(2)^2*4.9991 - V2(1)*V2(2)*(4.9991*cos((Del2(2)-Del2(1))*pi/180) - 15.2631*sin((Del2(2)-Del2(1))*pi/180));
    
    %Pre-processed and raw measurements:
    zpre_two(iteration) = zcentral{2}(10,4);
    z_conv(iteration) = zdata2(18,4);
end

%% Calculating results and displaying
%Calculate true measurement:
save('realestimate')
zreal = Vreal(2)^2*4.9991 - Vreal(1)*Vreal(2)*(4.9991*cos((Delreal(2)-Delreal(1))*pi/180) - 15.2631*sin((Delreal(2)-Delreal(1))*pi/180));

%Calculating estimate errors:
err1 =  zest_two_2_without - zreal;
err2 = zest_two_2-zreal;
err3= zest_conv_2-zreal;

%Calculating the estimate variances from samples:
v2ariance1 = sqrt(var(err1));
v2ariance2 = sqrt(var(err2));
v2ariance3 = sqrt(var(err3));

%Creating box plot:
figure(12)
boxplot([err1, err2, err3], 'Labels', {'Two-level SE without central BD detection', 'Two-level SE','Conventional SE'});
ylabel('Estimate error')
grid on